aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/true_talk/tt_concept.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/true_talk/tt_concept.h')
-rw-r--r--engines/titanic/true_talk/tt_concept.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/engines/titanic/true_talk/tt_concept.h b/engines/titanic/true_talk/tt_concept.h
index d28ac57575..ae956c14f1 100644
--- a/engines/titanic/true_talk/tt_concept.h
+++ b/engines/titanic/true_talk/tt_concept.h
@@ -69,9 +69,9 @@ private:
void reset();
/**
* Copy auxiliary data from the specified source concept
*/
- void copyFrom(TTconcept &src);
+ void initialize(TTconcept &src);
public:
TTconcept *_nextP;
public:
@@ -87,6 +87,11 @@ public:
void deleteSiblings();
/**
+ * Copies data from a source concept
+ */
+ void copyFrom(TTconcept *src);
+
+ /**
* Compares the name of the associated word, if any,
* to the passed string
*/
@@ -69,9 +69,9 @@ private:
void reset();
/**
- * Copy auxiliary data from the specified source concept
+ * Initialize inner data for the concept from a given source concept
*/